/*
-----------------------------------------------------
   Application Name: "CDRDB"
          Author(s): David Goodwin
          Copyright: (C) Copyright David Goodwin, 2010
            License: GNU General Public License
-----------------------------------------------------
        This file is part of "CDRDB".

    This is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This software is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this software; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

        File Notes:
        ------------------
*/

#include "databaseproperties.h"
#include "ui_databaseproperties.h"

#include <QSqlQuery>
#include <QSqlError>
#include <QtDebug>
#include <QMessageBox>

DatabaseProperties::DatabaseProperties(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::DatabaseProperties)
{
    ui->setupUi(this);

    connect(ui->buttonBox,SIGNAL(accepted()),this,SLOT(acceptAndCommit()));

    // get version info
    QString base = "SELECT DataValue FROM DBMetaData WHERE DBMetaDataType_ID = 1 AND DataKey=";

    QSqlQuery q(base + "'DBType'");
    q.first();
    QString dbtype = q.value(0).toString();

    q.exec(base + "'DBVersion'");
    q.first();
    QString dbversion = q.value(0).toString();

    q.exec(base + "'DBMinProgramVersion'");
    q.first();
    QString dbMinVersion = q.value(0).toString();

    q.exec(base + "'DBGenerator'");
    q.first();
    QString dbGenerator = q.value(0).toString();

    ui->leDBType->setText(dbtype);
    ui->leGenerator->setText(dbGenerator);
    ui->leVersion->setText(dbversion);
    ui->leMinPrgVers->setText(dbMinVersion);

    base = "SELECT DataValue FROM DBMetaData WHERE DBMetaDataType_ID = 2 AND DataKey=";

    q.exec(base + "'Author'");
    if (!q.first()) {
        qDebug() << "No Author record. Creating one now.";
        QSqlQuery insert("INSERT INTO DBMetaData(DBMetaDataType_ID,DataKey,DataValue) VALUES(2,'Author','')");
        if (insert.lastError().type() != QSqlError::NoError) {
            qDebug() << "Failed to create record.";
        }
        q.exec();
        q.first();
    }
    QString author = q.value(0).toString();

    q.exec(base + "'Comments'");
    if (!q.first()) {
        qDebug() << "No Comments record. Creating one now.";
        QSqlQuery insert("INSERT INTO DBMetaData(DBMetaDataType_ID,DataKey,DataValue) VALUES(2,'Comments','')");
        if (insert.lastError().type() != QSqlError::NoError) {
            qDebug() << "Failed to create record.";
        }
        q.exec();
        q.first();
    }
    QString comments = q.value(0).toString();

    ui->leAuthor->setText(author);
    ui->pteComments->setPlainText(comments);
}

DatabaseProperties::~DatabaseProperties()
{
    delete ui;
}

void DatabaseProperties::changeEvent(QEvent *e)
{
    QDialog::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void DatabaseProperties::acceptAndCommit() {
    QString base = "UPDATE DBMetaData SET DataValue=:value WHERE DBMetaDataType_ID=2 AND DataKey=:key";

    QSqlQuery q;
    q.prepare(base);
    q.bindValue(":value",ui->leAuthor->text());
    q.bindValue(":key","Author");

    if (!q.exec()) {
        QSqlError err = q.lastError();
        QMessageBox::critical(this,"Error","Failed to update database with new Author value. Error " + QString::number(err.number()) + " (" + err.text() + ")");
        return;
    }

    q.bindValue(":value",ui->pteComments->toPlainText());
    q.bindValue(":key","Comments");

    if (!q.exec()) {
        QSqlError err = q.lastError();
        QMessageBox::critical(this,"Error","Failed to update database with new Comments value. Error " + QString::number(err.number()) + " (" + err.text() + ")");
        return;
    }

    accept();
}
