PRAGMA foreign_keys=ON;

BEGIN TRANSACTION;

CREATE TABLE Disc (
	Disc_ID INTEGER PRIMARY KEY,
	SeriesNumber INTEGER,
	DiscTitle TEXT,
	DiscText TEXT,
	MediaType_ID INTEGER,
	DiscCode TEXT,
	DiscDate TEXT,
	Location TEXT,
	PictureFile TEXT,
	ImageFileHash TEXT,
	FOREIGN KEY(MediaType_ID) REFERENCES MediaType(MediaType_ID)
);

CREATE TABLE MediaType (
	MediaType_ID INTEGER PRIMARY KEY,
	Name TEXT,
	Description TEXT
);


CREATE TABLE Hashes (
	Sum_ID INTEGER PRIMARY KEY,
	Hash TEXT,
	Filename TEXT
);


CREATE TABLE DBMetaDataType (
	DBMetaDataType_ID INTEGER PRIMARY KEY,
	Name TEXT
);


CREATE TABLE DBMetaData (
	DBMetaData_ID INTEGER PRIMARY KEY,
	DBMetaDataType_ID INTEGER,
	DataKey TEXT,
	DataValue TEXT,
	FOREIGN KEY(DBMetaDataType_ID) REFERENCES DBMetaDataType(DBMetaDataType_ID)
);

CREATE INDEX indHash ON Hashes(Hash);

CREATE VIEW qry_MainDiscView AS
	SELECT
		d.Disc_ID AS '#',
		d.DiscTitle AS 'Title',
		d.DiscCode AS 'Code',
		d.DiscDate AS 'Date',
		d.SeriesNumber AS 'Series Number',
		d.Location AS 'Storage Location',
		mt.Name AS 'Media Type'
	FROM
		Disc d
		LEFT JOIN MediaType mt ON d.MediaType_ID = mt.MediaType_ID
;

CREATE VIEW qry_DiscHash AS
	SELECT
		h.Hash,
		h.Filename,
		d.Disc_ID
	FROM
		Hashes h
		LEFT JOIN Disc d ON d.ImageFileHash = h.hash
;


INSERT INTO DBMetaDataType(DBMetaDataType_ID,Name) Values(1,'DBInfo');
INSERT INTO DBMetaDataType(DBMetaDataType_ID,Name) Values(2,'DBProperties');
INSERT INTO DBMetaDataType(DBMetaDataType_ID,Name) Values(3,'PRGSettingsOverride');

INSERT INTO DBMetaData(DBMetaDataType_ID,DataKey,DataValue) Values(1,'DBType','CDRIMGDB');
INSERT INTO DBMetaData(DBMetaDataType_ID,DataKey,DataValue) Values(1,'DBGenerator','schema.sql');

INSERT INTO DBMetaData(DBMetaDataType_ID,DataKey,DataValue) Values(1,'DBVersion','1.0.0');

INSERT INTO DBMetaData(DBMetaDataType_ID,DataKey,DataValue) Values(1,'DBMinProgramVersion','1.0.0');

INSERT INTO MediaType VALUES(1,'CD-R','Recordable CD');
INSERT INTO MediaType VALUES(2,'CD-RW','Rewritable CD');
INSERT INTO MediaType VALUES(3,'CD-ROM','Pressed CD');
INSERT INTO MediaType VALUES(4,'DVD+R','DVD+R Recordable disc');
INSERT INTO MediaType VALUES(5,'DVD-R','DVD-R Recordable disc');
INSERT INTO MediaType VALUES(6,'DVD+RW','DVD+RW Rewritable disc');
INSERT INTO MediaType VALUES(7,'DVD-RW','DVD-RW Rewritable disc');
INSERT INTO MediaType VALUES(8,'DVD-RAM','DVD-RAM Randomly-accessable rewritable disc');
INSERT INTO MediaType VALUES(9,'DVD-ROM','Pressed DVD');

COMMIT;
