/*
-----------------------------------------------------
   Application Name: "CDRDB"
          Author(s): David Goodwin
          Copyright: (C) Copyright David Goodwin, 2010
            License: GNU General Public License
-----------------------------------------------------
        This file is part of "CDRDB".

    This is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This software is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this software; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

        File Notes:
        ------------------
*/

#include "discdialog.h"
#include "ui_discdialog.h"
#include "util.h"

#include <QSqlRelationalDelegate>
#include <QFileDialog>
#include <QSettings>
#include <QDesktopServices>
#include <QUrl>
#include <QtDebug>
#include <QScopedPointer>

DiscDialog::DiscDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::DiscDialog)
{
    ui->setupUi(this);
    connect(ui->bbAdd,SIGNAL(accepted()),this,SLOT(acceptAndCommit()));
    connect(ui->bbAdd,SIGNAL(rejected()),this,SLOT(rejectAndClose()));
    connect(ui->bbView,SIGNAL(rejected()),this,SLOT(rejectAndClose()));
    connect(ui->pbViewPicture,SIGNAL(clicked()),this,SLOT(viewImage()));
}

DiscDialog::~DiscDialog()
{
    delete ui;
}

void DiscDialog::changeEvent(QEvent *e)
{
    QDialog::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void DiscDialog::newDisc() {
    // Setup the relational table model
    model.setTable("Disc");
    model.setRelation(4,QSqlRelation("MediaType","MediaType_ID","Name"));

    // Insert a new row
    model.insertRow(model.rowCount());

    // Configure relations for individual columns
    ui->cmbMediaType->setModel(model.relationModel(4));
    ui->cmbMediaType->setModelColumn(model.relationModel(4)->fieldIndex("Name"));

    // Setup the data widget mapper
    mapper.setModel(&model);
    mapper.setSubmitPolicy(QDataWidgetMapper::ManualSubmit);
    mapper.setItemDelegate(new QSqlRelationalDelegate(&mapper));
    mapper.addMapping(ui->sbSeriesNumber,1);
    mapper.addMapping(ui->leTitle,2);
    mapper.addMapping(ui->pteDiscText,3);
    mapper.addMapping(ui->cmbMediaType,4);
    mapper.addMapping(ui->leDiscCode,5);
    mapper.addMapping(ui->deDate,6);
    mapper.addMapping(ui->leStorageLocation,7);
    mapper.addMapping(ui->lePictureFilename,8);
    mapper.addMapping(ui->leImageHash,9);
    mapper.toLast();

    ui->leImageHash->setVisible(true);
    ui->lblImagehash->setVisible(true);
    ui->lblImageFiles->setVisible(false);
    ui->tvImageFiles->setVisible(false);
    ui->pbViewPicture->setVisible(false);
    ui->bbView->setVisible(false);

    setWindowTitle("New Disc");
}

void DiscDialog::showDisc(int discID) {
    // Setup the relational table model
    model.setTable("Disc");
    model.setRelation(4,QSqlRelation("MediaType","MediaType_ID","Name"));

    model.setFilter("Disc_ID = " + QString::number(discID));
    model.select();

    // Configure relations for individual columns
    ui->cmbMediaType->setModel(model.relationModel(4));
    ui->cmbMediaType->setModelColumn(model.relationModel(4)->fieldIndex("Name"));

    // Setup the data widget mapper
    mapper.setModel(&model);
    mapper.setSubmitPolicy(QDataWidgetMapper::ManualSubmit);
    mapper.setItemDelegate(new QSqlRelationalDelegate(&mapper));
    mapper.addMapping(ui->sbSeriesNumber,1);
    mapper.addMapping(ui->leTitle,2);
    mapper.addMapping(ui->pteDiscText,3);
    mapper.addMapping(ui->cmbMediaType,4);
    mapper.addMapping(ui->leDiscCode,5);
    mapper.addMapping(ui->deDate,6);
    mapper.addMapping(ui->leStorageLocation,7);
    mapper.addMapping(ui->lePictureFilename,8);
    mapper.addMapping(ui->leImageHash,9);
    mapper.toLast();

    ui->sbSeriesNumber->setReadOnly(true);
    ui->leTitle->setReadOnly(true);
    ui->pteDiscText->setReadOnly(true);
    ui->cmbMediaType->setEnabled(false);
    ui->leDiscCode->setReadOnly(true);
    ui->deDate->setReadOnly(true);
    ui->leStorageLocation->setReadOnly(true);
    ui->lePictureFilename->setReadOnly(true);
    ui->leImageHash->setReadOnly(true);

    ui->leImageHash->setVisible(false);
    ui->lblImagehash->setVisible(false);
    ui->lblImageFiles->setVisible(true);
    ui->tvImageFiles->setVisible(true);
    ui->pbViewPicture->setVisible(true);
    ui->bbAdd->setVisible(false);

    fileModel.setQuery("SELECT ");

    fileModel.setQuery("SELECT Hash AS 'Hash', Filename AS 'File Name' FROM qry_DiscHash WHERE Disc_ID = " + QString::number(discID));
    ui->tvImageFiles->setModel(&fileModel);
    ui->tvImageFiles->resizeColumnsToContents();

    // Disable the view picture push button when there is nothing to view
    ui->pbViewPicture->setEnabled(!ui->lePictureFilename->text().isEmpty());

    setWindowTitle("Disc Information");
}

void DiscDialog::acceptAndCommit() {

    // Submit changes to database.
    mapper.submit();
    emit refreshRequested();

    accept();

    if (mSelfCleanup)
        this->deleteLater();
}

void DiscDialog::rejectAndClose() {

    reject();

    if (mSelfCleanup)
        this->deleteLater();
}

void DiscDialog::viewImage() {
    if (!ui->lePictureFilename->text().isEmpty()) {
        QScopedPointer<QSettings> settings;
        settings.reset(Util::getNewQSettings());

        QString url = "file:///";
        url += settings->value("DefaultImageDir",QDir::currentPath()).toString();
        if (!url.endsWith("/")) url += "/";
        url += ui->lePictureFilename->text();
        qDebug() << "Viewing image " << url;
        QDesktopServices::openUrl(QUrl(url, QUrl::TolerantMode));
    }
}
