/*
-----------------------------------------------------
   Application Name: "CDRDB"
          Author(s): David Goodwin
          Copyright: (C) Copyright David Goodwin, 2010
            License: GNU General Public License
-----------------------------------------------------
        This file is part of "CDRDB".

    This is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This software is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this software; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

        File Notes:
        ------------------
*/

#include "editdata.h"
#include "ui_editdata.h"
#include <QSqlRelationalDelegate>

EditData::EditData(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::EditData)
{
    ui->setupUi(this);
    connect(ui->buttonBox,SIGNAL(accepted()),this,SLOT(acceptAndCommit()));
    connect(ui->tbInsert,SIGNAL(clicked()),this,SLOT(insertRecord()));

    model.setTable("Disc");

    model.setRelation(4,QSqlRelation("MediaType","MediaType_ID","Name"));
    model.select();
    model.setEditStrategy(QSqlRelationalTableModel::OnManualSubmit);


    model.setHeaderData(0, Qt::Horizontal, QObject::tr("Hidden"));
    model.setHeaderData(1, Qt::Horizontal, QObject::tr("Series Number"));
    model.setHeaderData(2, Qt::Horizontal, QObject::tr("Disc Title"));
    model.setHeaderData(3, Qt::Horizontal, QObject::tr("Disc Text"));
    model.setHeaderData(4, Qt::Horizontal, QObject::tr("Media Type"));
    model.setHeaderData(5, Qt::Horizontal, QObject::tr("Disc Code"));
    model.setHeaderData(6, Qt::Horizontal, QObject::tr("Date"));
    model.setHeaderData(7, Qt::Horizontal, QObject::tr("Storage Location"));
    model.setHeaderData(8, Qt::Horizontal, QObject::tr("Picture File"));
    model.setHeaderData(9, Qt::Horizontal, QObject::tr("Hash"));


    ui->tableView->setModel(&model);
    ui->tableView->setItemDelegate(new QSqlRelationalDelegate(ui->tableView));
    ui->tableView->setColumnHidden(0,true);
    ui->tableView->resizeRowsToContents();
    ui->tableView->resizeColumnsToContents();
}

EditData::~EditData()
{
    delete ui;
}

void EditData::changeEvent(QEvent *e)
{
    QDialog::changeEvent(e);
    switch (e->type()) {
    case QEvent::LanguageChange:
        ui->retranslateUi(this);
        break;
    default:
        break;
    }
}

void EditData::acceptAndCommit() {
    model.submitAll();
    accept();
}

void EditData::insertRecord() {
    model.insertRow(model.rowCount());
}
